Method: YUI::JavaScriptCompressor#initialize
- Defined in:
- lib/yui/compressor.rb
#initialize(options = {}) ⇒ JavaScriptCompressor
Creates a new YUI::JavaScriptCompressor for minifying JavaScript code.
Options are:
:charset-
Specifies the character encoding to use. Defaults to
"utf-8". :line_break-
By default, JavaScript will be compressed onto a single line. Use this option to specify the maximum number of characters in each line before a newline is added. If
:line_breakis 0, a newline is added after each JavaScript statement. :munge-
Specifies whether YUI Compressor should shorten local variable names when possible. Defaults to
false. :optimize-
Specifies whether YUI Compressor should optimize JavaScript object property access and object literal declarations to use as few characters as possible. Defaults to
true. :preserve_semicolons-
Defaults to
false. Iftrue, YUI Compressor will ensure semicolons exist after each statement to appease tools like JSLint.
215 216 217 |
# File 'lib/yui/compressor.rb', line 215 def initialize( = {}) super end |